package com.elitesland.demo.controller;

import com.alibaba.fastjson.JSONObject;
import com.elitesland.Utils.QueueUtils;
import com.elitesland.Utils.QueueParmas;
import com.elitesland.common.dto.product.DemoProductDTO;
import com.elitesland.common.dto.user.DemoUserDTO;
import com.elitesland.common.rpc.demo.DemoRpcProductService;
import com.elitesland.common.rpc.demo.DemoRpcUserService;
import com.elitesland.core.base.ApiCode;
import com.elitesland.core.base.ApiResult;
import com.elitesland.core.exception.BusinessException;
import com.elitesland.demo.service.AfterSaleService;
import com.elitesland.demo.service.DemoService;
import com.elitesland.system.service.SysUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import lombok.val;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestTemplate;

@RestController
@Slf4j
@RequiredArgsConstructor
@RequestMapping("/demo")
@Api(value = "框架测试", tags = {"框架测试"})
public class DemoController {

    private  DemoService demoService;

    private final AfterSaleService afterSaleService;


    @DubboReference(version = "${provider.service.version}")
    private DemoRpcUserService demoRpcUserService;

    @DubboReference(version = "${provider.service.version}")
    private DemoRpcProductService demoRpcProductService;

    @Autowired
    public void setDemoService(DemoService demoService) {
        this.demoService = demoService;
    }

    @GetMapping("/nativesql")
    @ApiOperation("测试架构")
    public ApiResult<Object> select() {
        demoService.queryBySql();
        return ApiResult.ok("123455");
    }

    @GetMapping("/queue")
    @ApiOperation("叫号系统测试")
    public ApiResult<String> queue() {
        String s = "";
        try {
            s = QueueUtils.queues("http://demo.fafa.com.cn/yd-queue-api/api/serviceOrder/testApi","6663c554-4a8d-4f59-bf8c-c83b55b20699",new QueueParmas());
        } catch (Exception e) {
            e.printStackTrace();
        }

        return ApiResult.ok(s);
    }

    @GetMapping("/updataOrder")
    @ApiOperation("订单更新")
    public ApiResult<String> updataOrder() {
        String s = "";
        try {
            String url="http://demo.fafa.com.cn/yd-queue-api/api/serviceOrder/updateOrderInfo/20210202910905";
            String token="6663c554-4a8d-4f59-bf8c-c83b55b20699";
            HttpHeaders httpHeaders = new HttpHeaders();
            httpHeaders.set("Content-Type", "application/json");
            val params = new JSONObject();
            params.put("status","pretesting");
            params.put("pretestEmpCode","lis01");
            params.put("pretestEmpName","李四");
            params.put("pretestStart","2020-02-02 14:00:00");
            s=QueueUtils.queue(url,token,params,httpHeaders,HttpMethod.POST);
        } catch (Exception e) {
            e.printStackTrace();
        }

        return ApiResult.ok(s);
    }

    @ApiOperation("通过demo远程调用用户服务-测试演示")
    @PostMapping("/getUser")
    public ApiResult<Object> getUser(DemoUserDTO userDTO){
        ApiResult<Object> apiResult = null;
        try {
            apiResult = demoRpcUserService.getUser(userDTO);
        } catch (Exception e) {
            e.printStackTrace();
        }
        //业务逻辑
        return ApiResult.ok(apiResult);
    }

    @ApiOperation("通过demo远程调用商品服务-测试演示")
    @PostMapping("/getProduct")
    public ApiResult<Object> getProduct(DemoProductDTO productDTO){
        var apiResult = demoRpcProductService.getProduct(productDTO);
        //业务逻辑处理
        return ApiResult.ok(apiResult);
    }
    public static void main(String[] args) {
        val params = new JSONObject();
        params.put("status","pretesting");
        params.put("pretestEmpCode","lis01");
        params.put("pretestEmpName","李四");
        params.put("pretestStart","2020-02-02 14:00:00");
        //设置请求头
        val httpHeaders = new HttpHeaders();
        httpHeaders.set("Content-Type", "application/json");
        String TEST_URL = "http://demo.fafa.com.cn/yd-queue-api/api/serviceOrder/updateOrderInfo/20210202910905";
        val httpEntity = new HttpEntity<>(params, httpHeaders);
//        httpHeaders.set("Authorization", "6663c554-4a8d-4f59-bf8c-c83b55b20699");
//        httpHeaders.set("Authorization", token);
        // 发起请求
        RestTemplate restTemplate = new RestTemplate();
        ResponseEntity<String> result = restTemplate.exchange(TEST_URL, HttpMethod.POST, httpEntity, String.class);
        if (result.getStatusCode().compareTo(HttpStatus.OK) != 0) {
            throw new BusinessException(ApiCode.FAIL, "接口异常，请稍后重试");
        }
        System.out.println(result.getBody());
    }

    @ApiOperation("根据当前登录人，获取服务站员工，工位信息")
    @GetMapping("/getEmpAndWcData")
    public ApiResult<Object> getEmpAndWcData(){
        return ApiResult.ok(afterSaleService.getEmpAndWcData());
    }
}
